@@ -466,6 +466,7 @@ void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
 
   const DavCollection::List davCollections = fetchJob->collections();
   QSet<QString> seenCollectionsNames;
+  QSet<QString> seenCollectionsUrls;
 
   foreach ( const DavCollection &davCollection, davCollections ) {
     if ( mCollectionsWithTemporaryError.contains( davCollection.url() ) ) {
@@ -473,6 +474,11 @@ void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
       mCollectionsWithTemporaryError.removeOne( davCollection.url() );
     }
 
+    if ( seenCollectionsUrls.contains( davCollection.url() ) )
+      continue;
+    else
+      seenCollectionsUrls.insert( davCollection.url() );
+
     Akonadi::Collection collection;
     collection.setParentCollection( mDavCollectionRoot );
     collection.setRemoteId( davCollection.url() );
