@@ -21,7 +21,7 @@
 #define CALENDARHANDLER_H
 
 #include "incidencehandler.h"
-#include <kcal/event.h>
+#include <kcalcore/event.h>
 
 /**
 	@author Andras Mantia <amantia@kde.org>
@@ -29,15 +29,14 @@
 class CalendarHandler : public IncidenceHandler {
   Q_OBJECT
 public:
-  CalendarHandler();
+  explicit CalendarHandler( const Akonadi::Collection &imapCollection );
   virtual ~CalendarHandler();
   virtual QStringList contentMimeTypes();
   virtual QString iconName() const;
 
 private:
-  virtual QByteArray incidenceToXml(KCal::Incidence *incidence);
-  virtual KCal::Incidence* incidenceFromKolab(const KMime::Message::Ptr &data);
-  KCal::Event * calendarFromKolab(const KMime::Message::Ptr &data);
+  virtual QByteArray incidenceToXml( const KCalCore::Incidence::Ptr &incidence );
+  virtual KCalCore::Incidence::Ptr incidenceFromKolab( const KMime::Message::Ptr &data );
 };
 
 #endif
