@@ -22,22 +22,21 @@
 #define TASKSHANDLER_H
 
 #include "incidencehandler.h"
-#include <kcal/todo.h>
+#include <kcalcore/todo.h>
 
 /**
 	@author Andras Mantia <amantia@kde.org>
 */
 class TasksHandler : public IncidenceHandler {
 public:
-  TasksHandler();
+  explicit TasksHandler( const Akonadi::Collection &imapCollection );
   virtual ~TasksHandler();
   virtual QStringList contentMimeTypes();
   virtual QString iconName() const;
 
 private:
-  virtual QByteArray incidenceToXml(KCal::Incidence *incidence);
-  virtual KCal::Incidence* incidenceFromKolab(const KMime::Message::Ptr &data);
-  KCal::Todo *todoFromKolab(const KMime::Message::Ptr &data);
+  virtual QByteArray incidenceToXml( const KCalCore::Incidence::Ptr &incidence);
+  virtual KCalCore::Incidence::Ptr incidenceFromKolab( const KMime::Message::Ptr &data );
 
 };
 
