@@ -21,8 +21,10 @@
 #include "settings.h"
 #include "maildirsettingsadaptor.h"
 #include "configdialog.h"
+#include "retrieveitemsjob.h"
 
 #include <QtCore/QDir>
+#include <QtCore/QFileSystemWatcher>
 #include <QtDBus/QDBusConnection>
 
 #include <akonadi/kmime/messageparts.h>
@@ -30,8 +32,11 @@
 #include <akonadi/itemfetchscope.h>
 #include <akonadi/collectionfetchscope.h>
 #include <akonadi/cachepolicy.h>
+#include <akonadi/collectionfetchjob.h>
 #include <akonadi/dbusconnectionpool.h>
 
+#include <kmime/kmime_message.h>
+
 #include <kdebug.h>
 #include <kurl.h>
 #include <kfiledialog.h>
@@ -41,8 +46,6 @@
 
 #include "libmaildir/maildir.h"
 
-#include <kmime/kmime_message.h>
-
 using namespace Akonadi;
 using KPIM::Maildir;
 using namespace Akonadi_Maildir_Resource;
@@ -62,9 +65,28 @@ Maildir MaildirResource::maildirForCollection( const Collection &col ) const
   return parentMd.subFolder( col.remoteId() );
 }
 
+Collection MaildirResource::collectionForMaildir(const Maildir& md) const
+{
+  if ( !md.isValid() )
+    return Collection();
+
+  Collection col;
+  if ( md.path() == mSettings->path() ) {
+    col.setRemoteId( md.path() );
+    col.setParentCollection( Collection::root() );
+  } else {
+    const Collection parent = collectionForMaildir( md.parent() );
+    col.setRemoteId( md.name() );
+    col.setParentCollection( parent );
+  }
+
+  return col;
+}
+
 MaildirResource::MaildirResource( const QString &id )
     :ResourceBase( id ),
-    mSettings( new MaildirSettings( componentData().config() ) )
+    mSettings( new MaildirSettings( componentData().config() ) ),
+    m_fsWatcher( new QFileSystemWatcher( this ) )
 {
   new MaildirSettingsAdaptor( mSettings );
   DBusConnectionPool::threadConnection().registerObject( QLatin1String( "/Settings" ),
@@ -77,9 +99,20 @@ MaildirResource::MaildirResource( const QString &id )
   changeRecorder()->fetchCollection( true );
   changeRecorder()->itemFetchScope().fetchFullPayload( true );
   changeRecorder()->itemFetchScope().setAncestorRetrieval( ItemFetchScope::All );
+  changeRecorder()->itemFetchScope().setFetchModificationTime( false );
   changeRecorder()->collectionFetchScope().setAncestorRetrieval( CollectionFetchScope::All );
 
   setHierarchicalRemoteIdentifiersEnabled( true );
+
+  ItemFetchScope scope( changeRecorder()->itemFetchScope() );
+  scope.fetchFullPayload( false );
+  scope.fetchPayloadPart( MessagePart::Header );
+  scope.setAncestorRetrieval( ItemFetchScope::None );
+  setItemSynchronizationFetchScope( scope );
+
+  connect( m_fsWatcher, SIGNAL(directoryChanged(QString)), SLOT(slotDirChanged(QString)) );
+
+  synchronizeCollectionTree();
 }
 
 MaildirResource::~ MaildirResource()
@@ -261,6 +294,9 @@ void MaildirResource::itemRemoved(const Akonadi::Item & item)
 
 Collection::List MaildirResource::listRecursive( const Collection &root, const Maildir &dir )
 {
+  if ( !dir.isRoot() && mSettings->monitorFilesystem() )
+    m_fsWatcher->addPath( dir.path() + QDir::separator() + QLatin1String( "new" ) );
+
   Collection::List list;
   const QStringList mimeTypes = QStringList() << itemMimeType() << Collection::mimeType();
   foreach ( const QString &sub, dir.subFolderList() ) {
@@ -282,6 +318,9 @@ Collection::List MaildirResource::listRecursive( const Collection &root, const M
 
 void MaildirResource::retrieveCollections()
 {
+  if ( !m_fsWatcher->directories().isEmpty() )
+    m_fsWatcher->removePaths( m_fsWatcher->directories() );
+
   Maildir dir( mSettings->path(), mSettings->topLevelIsContainer() );
   QString errMsg;
   if ( !dir.isValid( errMsg ) ) {
@@ -297,6 +336,14 @@ void MaildirResource::retrieveCollections()
   root.setRights( Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem
                 | Collection::CanCreateCollection );
 
+  CachePolicy policy;
+  policy.setInheritFromParent( false );
+  policy.setSyncOnDemand( true );
+  policy.setLocalParts( QStringList() << MessagePart::Envelope );
+  policy.setCacheTimeout( 1 );
+  policy.setIntervalCheckTime( -1 );
+  root.setCachePolicy( policy );
+
   QStringList mimeTypes;
   mimeTypes << Collection::mimeType();
   if ( !mSettings->topLevelIsContainer() )
@@ -316,21 +363,18 @@ void MaildirResource::retrieveItems( const Akonadi::Collection & col )
     cancelTask( i18n("Maildir '%1' for collection '%2' is invalid.", md.path(), col.remoteId() ) );
     return;
   }
-  const QStringList entryList = md.entryList();
 
-  Item::List items;
-  foreach ( const QString &entry, entryList ) {
-    Item item;
-    item.setRemoteId( entry );
-    item.setMimeType( itemMimeType() );
-    item.setSize( md.size( entry ) );
-    KMime::Message *msg = new KMime::Message;
-    msg->setHead( KMime::CRLFtoLF( md.readEntryHeaders( entry ) ) );
-    msg->parse();
-    item.setPayload( KMime::Message::Ptr( msg ) );
-    items << item;
-  }
-  itemsRetrieved( items );
+  RetrieveItemsJob *job = new RetrieveItemsJob( col, md, this );
+  job->setMimeType( itemMimeType() );
+  connect( job, SIGNAL(result(KJob*)), SLOT(slotItemsRetrievalResult(KJob*)) );
+}
+
+void MaildirResource::slotItemsRetrievalResult ( KJob* job )
+{
+  if ( job->error() )
+    cancelTask( job->errorString() );
+  else
+    itemsRetrievalDone();
 }
 
 void MaildirResource::collectionAdded(const Collection & collection, const Collection &parent)
@@ -480,4 +524,36 @@ bool MaildirResource::ensureSaneConfiguration()
   return true;
 }
 
+void MaildirResource::slotDirChanged(const QString& dir)
+{
+  QDir d( dir );
+  if ( !d.cdUp() )
+    return;
+
+  const Maildir md( d.path() );
+  if ( !md.isValid() )
+    return;
+
+  const Collection col = collectionForMaildir( md );
+  if ( col.remoteId().isEmpty() ) {
+    kDebug() << "unable to find collection for path" << dir;
+    return;
+  }
+
+  CollectionFetchJob *job = new CollectionFetchJob( col, Akonadi::CollectionFetchJob::Base, this );
+  connect( job, SIGNAL(result(KJob*)), SLOT(fsWatchFetchResult(KJob*)) );
+}
+
+void MaildirResource::fsWatchFetchResult(KJob* job)
+{
+  if ( job->error() ) {
+    kDebug() << job->errorString();
+    return;
+  }
+  const Collection::List cols = qobject_cast<CollectionFetchJob*>( job )->collections();
+  if ( cols.isEmpty() )
+    return;
+  synchronizeCollection( cols.first().id() );
+}
+
 #include "maildirresource.moc"
