@@ -23,6 +23,7 @@
 #include <akonadi/collection.h>
 #include <akonadi/resourcebase.h>
 
+class QFileSystemWatcher;
 namespace Akonadi_Maildir_Resource
 {
 class MaildirSettings;
@@ -65,6 +66,9 @@ class MaildirResource : public Akonadi::ResourceBase, public Akonadi::AgentBase:
 
   private slots:
     void configurationChanged();
+    void slotItemsRetrievalResult(KJob* job);
+    void slotDirChanged( const QString &dir );
+    void fsWatchFetchResult( KJob* job );
 
   private:
     void ensureDirExists();
@@ -72,9 +76,12 @@ class MaildirResource : public Akonadi::ResourceBase, public Akonadi::AgentBase:
     Akonadi::Collection::List listRecursive( const Akonadi::Collection &root, const KPIM::Maildir &dir );
     /** Creates a maildir object for the collection @p col, given it has the full ancestor chain set. */
     KPIM::Maildir maildirForCollection( const Akonadi::Collection &col ) const;
+    /** Creates a collection object for the given maildir @p md. */
+    Akonadi::Collection collectionForMaildir( const KPIM::Maildir &md ) const;
 
   private:
     Akonadi_Maildir_Resource::MaildirSettings *mSettings;
+    QFileSystemWatcher *m_fsWatcher;
 
 };
 
