@@ -524,7 +524,7 @@ bool KMIndexReader::fillPartsCache( KMIndexData* msg, off_t indexOff, short int
       Q_ASSERT(mIndexSizeOfLong == len);
       if (mIndexSizeOfLong == sizeof(ret))
       {
-        kDebug( KDE_DEFAULT_DEBUG_AREA ) << "mIndexSizeOfLong == sizeof(ret)";
+        //kDebug( KDE_DEFAULT_DEBUG_AREA ) << "mIndexSizeOfLong == sizeof(ret)";
         // this memcpy replaces the original call to copy_from_stream
         // so that g_chunk_offset is not changed
         memcpy( &ret, g_chunk + g_chunk_offset, sizeof(ret) );
